this.name           = "planetaryCompass_worldScript.js";
this.author         = "Thargoid";
this.copyright      = "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description    = "World script for planetary compass OXP";
this.version        = "1.01";
"use strict";

this.startUp = function()
	{ 
	this.planetNames = [ "I", "II", "III", "IV", "V", "VI", "VII", "VIII", "IX", "X", "XI", "XII", "XIII", "XIV", "XV", "XVI", "XVII", "XVIII", "XIX", "XX" ];
	this.moonNames = new Array();
	
	if(worldScriptNames.length > 0) // scan for moon name pack scripts
		{
		var scriptCounter = 0 ; // reset the counter
		for(scriptCounter = 0;scriptCounter<worldScriptNames.length;scriptCounter++)
			{
			if(worldScriptNames[scriptCounter] && worldScripts[worldScriptNames[scriptCounter]] && worldScripts[worldScriptNames[scriptCounter]].$planetaryCompass_addMoonNames)
				{ worldScripts[worldScriptNames[scriptCounter]].$planetaryCompass_addMoonNames(); }
			}
		}
	
	if(this.moonNames.length === 0)
		{
		log("Planetary Compass", "No planetary compass moon name packs installed - please add at least one!");
		delete this.shipWillLaunchFromStation;
		delete this.shipExitedWitchspace;
		delete this.$setUpNames;
		delete this.$checkForSpecialPlanets;
		}
	}
	
this.shipWillLaunchFromStation = function(station)
	{
	this.shipExitedWitchspace();
	delete this.shipWillLaunchFromStation;
	}	

this.shipExitedWitchspace = function()
	{ this.scriptDelay = new Timer(this, this.$setUpNames, 0.25); }
	
this.$setUpNames = function()
	{
	this.$checkForSpecialPlanets();
	if(system.isInterstellarSpace || !system.sun || system.sun.isGoingNova || system.sun.hasGoneNova) { return; }

	function allPlanets(entity) {return entity.isPlanet}; 
	this.stellarArray = system.filteredEntities(this, allPlanets, system.sun); // use this instead of system.planets array to get order correct
		
	var moonRow = Math.floor(this.moonNames.length * system.scrambledPseudoRandomNumber(system.ID * galaxyNumber)); // chose a row from the name grid
	this.shuffleCount = 0;
	function shuffleMoons() 
		{
		this.shuffleCount++;
		return 0.5 - system.scrambledPseudoRandomNumber(system.ID + this.shuffleCount);
		}
	var systemMoons = this.moonNames[moonRow].sort(shuffleMoons); // shuffle the list of names in the row
	
	var moonCount = 0;
	var planetCount = 0;
	var loopCounter = 0;
	
	for(loopCounter = 0;loopCounter<this.stellarArray.length;loopCounter++)
		{
		planetCount %= this.planetNames.length; // as a fallback in case there are more entities than name row items
		moonCount %= systemMoons.length;
		if(this.stellarArray[loopCounter].displayName !== undefined || this.stellarArray[loopCounter].name !== undefined)
			{
			if(this.stellarArray[loopCounter].hasAtmosphere)
				{ 
				this.beacon = system.addVisualEffect("planetaryCompass_planet", this.stellarArray[loopCounter].position); 
				if(this.stellarArray[loopCounter].displayName !== undefined)
					{ this.beacon.displayName = this.stellarArray[loopCounter].displayName; }
				if(this.stellarArray[loopCounter].name !== undefined)
					{ this.beacon.name = this.stellarArray[loopCounter].name; }				
				planetCount++;
				}
			else
				{ 
				this.beacon = system.addVisualEffect("planetaryCompass_moon", this.stellarArray[loopCounter].position);
				if(this.stellarArray[loopCounter].displayName !== undefined)
					{ this.beacon.displayName = this.stellarArray[loopCounter].displayName; }
				if(this.stellarArray[loopCounter].name !== undefined)
					{ this.beacon.name = this.stellarArray[loopCounter].name; }				
				moonCount++;
				}
			continue; 
			}
			
		if(this.stellarArray[loopCounter].hasAtmosphere)
			{ 
			this.beacon = system.addVisualEffect("planetaryCompass_planet", this.stellarArray[loopCounter].position); 
			if(this.stellarArray[loopCounter].hasOwnProperty("isGasGiant") && this.stellarArray[loopCounter].isGasGiant)
				{ this.planetType = "Gas Giant"; }
			else
				{ this.planetType = "Planet"; }
				
			if(this.stellarArray[loopCounter].isMainPlanet)
				{ 
				this.beacon.name = system.name + " Prime";
				this.beacon.displayName = system.name + " Prime (" + this.planetType + ")";  
				}
			else
				{ 
				this.beacon.name = system.name + " " + this.planetNames[planetCount];
				this.beacon.displayName = system.name + " " + this.planetNames[planetCount] + " (" + this.planetType + ")"; 
				}
			planetCount++;
			}
		else
			{ 
			this.beacon = system.addVisualEffect("planetaryCompass_moon", this.stellarArray[loopCounter].position);
			this.beacon.name = systemMoons[moonCount];
			this.beacon.displayName = systemMoons[moonCount] + " (Moon)";
			moonCount++;
			}
		this.stellarArray[loopCounter].name = this.beacon.name;	
		this.stellarArray[loopCounter].displayName = this.beacon.displayName;	
		}
	}

this.$checkForSpecialPlanets = function()
	{	
	if(galaxyNumber === 0 && system.ID === 246) // if we're at Tianve (G0, S227), name the pulsar
		{
		for (let i=0; i<system.planets.length; i++) 
			{ 
			if(system.planets[i].texture === "tianve_pulsar.png") 
				{ system.planets[i].displayName = "Tianve Pulsar"; } 
			}
		return;	
		}
	}	